@@ -1,7 +1,6 @@
 """Module for containing CLI convenience functions"""
 from __future__ import print_function
 
-import getpass
 import logging
 import subprocess
 import tempfile
@@ -15,7 +14,7 @@ import requests
 from amplify_aws_utils.resource_helper import Jitter
 from aws_requests_auth.boto_utils import BotoAWSRequestsAuth
 
-from terrawrap.utils.git_utils import get_git_root
+from terrawrap.utils.git_utils import get_git_root, get_git_hash
 
 logger = logging.getLogger(__name__)
 
@@ -35,7 +34,6 @@ RETRIABLE_ERRORS = [
     'try again later',
     'handshake timeout',
     'SSL_ERROR_SYSCALL',
-    'ConditionalCheckFailedException',
     'Api Rate Limit Exceeded',
     'TooManyUpdates',
 ]
@@ -85,9 +83,9 @@ def execute_command(
         }
 
     # Get time - nanoseconds since epoch
-    start_time = time.time_ns()
+    start_time = int(time.time())
 
-    if audit_api_url and kwargs['cwd']:
+    if audit_api_url and kwargs['cwd'] and 'apply' in args:
         # Call _post_audit_info for working directory, setting status to 'in progress'
         _post_audit_info(
             audit_api_url=audit_api_url,
@@ -125,7 +123,7 @@ def execute_command(
 
         time_passed = jitter.backoff()
 
-    if audit_api_url and kwargs['cwd']:
+    if audit_api_url and kwargs['cwd'] and 'apply' in args:
         # Call _post_audit_info again, this time to update the 'in progress' entry with new status and output
         _post_audit_info(
             audit_api_url=audit_api_url,
@@ -215,18 +213,15 @@ def _post_audit_info(
         update: bool = False
 ):
     root = get_git_root(path)
+    sha = get_git_hash(path)
+
     path = path.replace(root, '')
 
     status = Status.IN_PROGRESS if exit_code is None else (
         Status.SUCCESS if exit_code == 0 else Status.FAILED
     )
 
-    try:
-        user = getpass.getuser()
-    except Exception:
-        user = 'System'
-
-    logger.info('Attempting to send data to Audit API: %s run by %s(%s)', path, user, status)
+    logger.info('Attempting to send data to Audit API: %s - %s', path, status)
 
     url = (audit_api_url + AUDIT_UPDATE_PATH) if update else (audit_api_url + AUDIT_POST_PATH)
 
@@ -236,6 +231,8 @@ def _post_audit_info(
         aws_service='execute-api'
     )
 
+    stdout_str = ''.join(stdout) if stdout else ''
+
     try:
         requests.post(
             url=url,
@@ -244,9 +241,10 @@ def _post_audit_info(
                 'directory': path,
                 'start_time': start_time,
                 'status': status,
-                'run_by': user,
-                'output': stdout or ''
-            }
+                'output': stdout_str,
+                'git_hash': sha
+            },
+            timeout=30,
         )
         logger.info('Successfully posted data to provided url: %s', audit_api_url)
     except requests.exceptions.RequestException:
