@@ -51,14 +51,14 @@ def _get_modules_for_file(directory: str, file_name: str) -> Tuple[str, Set[str]
     :return:
     """
     modules = set()
-    with open(directory + '/' + file_name, 'r') as file:
+    with open(directory + '/' + file_name, 'r', encoding='utf-8') as file:
         try:
             tf_info = hcl2.load(file)
             for module in tf_info.get('module', []):
                 for module_config in module.values():
                     modules.add(os.path.normpath(module_config['source']))
         except Exception:
-            print('Error while parsing file %s' % file.name)
+            print(f'Error while parsing file {file.name}')
             raise
 
     return directory, modules
